/* hiv_horizons.do */
/* created by kim yi dionne, last edited 03 February 2009 */
/* Stata commands to produce tables and graphs for CPS article on executive time horizons and response to AIDS in Africa */

log using hivhorizons_statalog, append

/* instructs Stata which file to use */
use "/Users/kimg/Documents/Academic/hivaids/multivariate_2004/only_africa/east_southern.dta"

/* lists countries with HIV prevalence (from 2003) and their API Scores (from 2003) */
/* TABLE 1 */
list country hiv_2003 polplanning 

/* OLS Test #1: models on API score (polplanning) */

/* MODEL 1 */
reg polplanning hiv_2001l gdp_2001l 

/* MODEL 2 */
reg polplanning hiv_2001l gdp_2001l margin auth_horizon auth_dummy 

/* creates residuals from regression on API score */
predict policy_residuals

/* creates a residual plot on API score for Democratic Executives */
/* FIGURE 1 */
avplot margin, mlabel(country) mlabsize(vsmall) mlabcolor(black)  plotregion(style(none)) xtitle("e (Democratic Executive Time Horizon | X)", size(small)) ytitle("e (API Policy and Planning Score | X)", size(small)) scheme(s1mono) legend(off) note(Plot of residual of Y regressed on X against the residual of X from Model 2 regression, justification(center)) ylabel( , angle(0)) subtitle("Time Horizon and HIV Policy Score based on Democratic Executive’s Margin of Victory", size(small))
graph export "/Users/dadakim/Documents/!!!working_papers/HIVhorizons/images/API_dem.tif", replace

/* creates a residual plot on API score for Authoritarian Executives */
/* FIGURE 2 */
avplot auth_horizon, mlabel(country) mlabsize(vsmall) mlabcolor(black)  plotregion(style(none)) xtitle("e (Authoritarian Executive Time Horizon | X)", size(small)) ytitle("e (API Policy and Planning Score | X)", size(small)) scheme(s1mono) leg(off) note(Plot of residual of Y regressed on X against the residual of X from Model 2 regression, justification(center)) ylabel( , angle(0)) subtitle("Time Horizon and HIV Policy Score based on Authoritarian Executive’s Probability of Failure", size(small))
graph export "/Users/dadakim/Documents/!!!working_papers/HIVhorizons/images/API_auth.tif", replace

/* OLS Test #2: models on govt health spending (pubspnd) */

/* MODEL 1 */
reg pubspnd hiv_2001l gdp_2001l 

/* MODEL 2 */
reg pubspnd hiv_2001l gdp_2001l margin auth_horizon auth_dummy 

/* creates residuals from regression on govt health spending */
predict spend_residuals

/* creates a residual plot on govt health spending for Democratic Executives */
/* FIGURE 3 */
avplot margin, mlabel(country) mlabsize(vsmall) mlabcolor(black)  plotregion(style(none)) xtitle("e (Democratic Executive Time Horizon | X)", size(small)) ytitle("e (Government Health Expenditure | X)", size(small)) scheme(s1mono) leg(off) note(Plot of residual of Y regressed on X against the residual of X from Model 2 regression, justification(center)) ylabel( , angle(0)) subtitle("Time Horizon and Government Health Spending based on Democratic Executive’s Margin of Victory", size(small))
graph export "/Users/dadakim/Documents/!!!working_papers/HIVhorizons/images/spend_dem.tif", replace

/* creates a residual plot on govt health spending for Authoritarian Executives */
/* FIGURE 4 */
avplot auth_horizon, mlabel(country) mlabsize(vsmall) mlabcolor(black)  plotregion(style(none)) xtitle("e (Authoritarian Executive Time Horizon | X)", size(small)) ytitle("e (Government Health Expenditure | X)", size(small)) scheme(s1mono) leg(off) note(Plot of residual of Y regressed on X against the residual of X from Model 2 regression, justification(center)) ylabel( , angle(0)) subtitle("Time Horizon and Government Health Spending based on Authoritarian Executive’s Probability of Failure", size(small))
graph export "/Users/dadakim/Documents/!!!working_papers/HIVhorizons/images/spend_auth.tif", replace

/* OLS Test #3: models on govt AIDS spending (domestic_AIDS_spending_percap) */

/* MODEL 1 */
reg domestic_AIDS_spending_percap_ln hiv_2001l gdp_2001l 

/* MODEL 2 */
reg domestic_AIDS_spending_percap_ln hiv_2001l gdp_2001l margin auth_horizon auth_dummy 

/* creates residuals from regression on govt AIDS spending */
predict spend_AIDS_residuals

/* creates a residual plot on govt AIDS spending for Democratic Executives */
/* FIGURE 5 */
avplot margin, mlabel(country) mlabsize(vsmall) mlabcolor(black)  plotregion(style(none)) xtitle("e (Democratic Executive Time Horizon | X)", size(small)) ytitle("e (Government AIDS Expenditure | X)", size(small)) scheme(s1mono) leg(off) note(Plot of residual of Y regressed on X against the residual of X from Model 2 regression, justification(center)) ylabel( , angle(0)) subtitle("Time Horizon and Government AIDS Spending based on Democratic Executive’s Margin of Victory", size(small))
graph export "/Users/dadakim/Documents/!!!working_papers/HIVhorizons/images/spend_AIDS_dem.tif", replace

/* creates a residual plot on govt AIDS spending for Authoritarian Executives */
/* FIGURE 6 */
avplot auth_horizon, mlabel(country) mlabsize(vsmall) mlabcolor(black)  plotregion(style(none)) xtitle("e (Authoritarian Executive Time Horizon | X)", size(small)) ytitle("e (Government AIDS Expenditure | X)", size(small)) scheme(s1mono) leg(off) note(Plot of residual of Y regressed on X against the residual of X from Model 2 regression, justification(center)) ylabel( , angle(0)) subtitle("Time Horizon and Government AIDS Spending based on Authoritarian Executive’s Probability of Failure", size(small))
graph export "/Users/dadakim/Documents/!!!working_papers/HIVhorizons/images/spend_AIDS_auth.tif", replace

log close

/* ADDITIONAL NOTES */

/* code used to create the domestic spending per capita variable: */
/* gen domestic_AIDS_spending_percap = domestic_AIDS_spending / pop_2001 */

/* code used to create the logged domestic spending per capita variable: */
/* gen domestic_AIDS_spending_percap_ln = ln(domestic_AIDS_spending_percap) */